@@ -1,7 +1,16 @@
 __all__ = [
-    'ImproperlyConfigured', 'ElasticsearchException', 'SerializationError',
-    'TransportError', 'NotFoundError', 'ConflictError', 'RequestError', 'ConnectionError',
-    'SSLError', 'ConnectionTimeout', 'AuthenticationException', 'AuthorizationException'
+    "ImproperlyConfigured",
+    "ElasticsearchException",
+    "SerializationError",
+    "TransportError",
+    "NotFoundError",
+    "ConflictError",
+    "RequestError",
+    "ConnectionError",
+    "SSLError",
+    "ConnectionTimeout",
+    "AuthenticationException",
+    "AuthorizationException",
 ]
 
 
@@ -31,6 +40,7 @@ class TransportError(ElasticsearchException):
     an actual connection error happens; in that case the ``status_code`` will
     be set to ``'N/A'``.
     """
+
     @property
     def status_code(self):
         """
@@ -53,32 +63,43 @@ class TransportError(ElasticsearchException):
         return self.args[2]
 
     def __str__(self):
-        cause = ''
+        cause = ""
         try:
-            if self.info and 'error' in self.info:
-                if isinstance(self.info['error'], dict):
-                    root_cause = self.info['error']['root_cause'][0]
-                    cause = ', '.join(filter(None, [repr(root_cause['reason']), root_cause.get('resource.id'),
-                                                    root_cause.get('resource.type')]))
+            if self.info and "error" in self.info:
+                if isinstance(self.info["error"], dict):
+                    root_cause = self.info["error"]["root_cause"][0]
+                    cause = ", ".join(
+                        filter(
+                            None,
+                            [
+                                repr(root_cause["reason"]),
+                                root_cause.get("resource.id"),
+                                root_cause.get("resource.type"),
+                            ],
+                        )
+                    )
 
                 else:
-                    cause = repr(self.info['error'])
+                    cause = repr(self.info["error"])
         except LookupError:
             pass
-        msg = ', '.join(filter(None, [str(self.status_code), repr(self.error), cause]))
-        return '%s(%s)' % (self.__class__.__name__, msg)
+        msg = ", ".join(filter(None, [str(self.status_code), repr(self.error), cause]))
+        return "%s(%s)" % (self.__class__.__name__, msg)
 
 
 class ConnectionError(TransportError):
     """
     Error raised when there was an exception while talking to ES. Original
     exception from the underlying :class:`~elasticsearch.Connection`
-    implementation is available as ``.info.``
+    implementation is available as ``.info``.
     """
 
     def __str__(self):
-        return 'ConnectionError(%s) caused by: %s(%s)' % (
-            self.error, self.info.__class__.__name__, self.info)
+        return "ConnectionError(%s) caused by: %s(%s)" % (
+            self.error,
+            self.info.__class__.__name__,
+            self.info,
+        )
 
 
 class SSLError(ConnectionError):
@@ -89,8 +110,10 @@ class ConnectionTimeout(ConnectionError):
     """ A network timeout. Doesn't cause a node retry by default. """
 
     def __str__(self):
-        return 'ConnectionTimeout caused by - %s(%s)' % (
-            self.info.__class__.__name__, self.info)
+        return "ConnectionTimeout caused by - %s(%s)" % (
+            self.info.__class__.__name__,
+            self.info,
+        )
 
 
 class NotFoundError(TransportError):
